Commit f1ee06608a for wordpress.org

commit f1ee06608a9946b21cee211aadec11cb7efbaf2b
Author: johnbillion <johnbillion@git.wordpress.org>
Date:   Fri Oct 9 11:12:49 2026 +0000

    Users: Fix the admin email placeholder in the Application Password Created email notification.

    Developed in https://github.com/WordPress/wordpress-develop/pull/14118

    Props johnbillion, peterwilsoncc, audrasjb.

    See #63927

    Built from https://develop.svn.wordpress.org/trunk@64253


    git-svn-id: http://core.svn.wordpress.org/trunk@63404 1a063a9b-81f0-0310-95a4-ce76da25c4cd

diff --git a/wp-includes/version.php b/wp-includes/version.php
index b733294c23..73956434d6 100644
--- a/wp-includes/version.php
+++ b/wp-includes/version.php
@@ -16,7 +16,7 @@
  *
  * @global string $wp_version
  */
-$wp_version = '7.2-alpha-64252';
+$wp_version = '7.2-alpha-64253';

 /**
  * Holds the WordPress DB revision, increments when changes are made to the WordPress DB schema.
diff --git a/wp-includes/functions.php b/wp-includes/functions.php
index 114a9484f5..b70fff7132 100644
--- a/wp-includes/functions.php
+++ b/wp-includes/functions.php
@@ -9575,7 +9575,7 @@ function wp_application_password_created_notification( $user_id, $new_item ) {
 		return;
 	}

 	/* translators: Do not translate USERNAME, APPLICATION_PASSWORD_NAME, SITENAME, SITEURL, EMAIL: those are placeholders. */
 	$application_password_create_text = __(
 		'Hi ###USERNAME###,

@@ -9621,6 +9621,7 @@ All at ###SITENAME###
 	 *         The following strings have a special meaning and will get replaced dynamically:
 	 *          - `###USERNAME###`                  The user's display name.
 	 *          - `###APPLICATION_PASSWORD_NAME###` The name of the application password.
+	 *          - `###ADMIN_EMAIL###`               The admin email in case this was unexpected.
 	 *          - `###EMAIL###`                     The user's email address.
 	 *          - `###SITENAME###`                  The name of the site.
 	 *          - `###SITEURL###`                   The URL to the site.
@@ -9633,6 +9634,7 @@ All at ###SITENAME###

 	$email['message'] = str_replace( '###USERNAME###', $user->display_name, $email['message'] );
 	$email['message'] = str_replace( '###APPLICATION_PASSWORD_NAME###', $new_item['name'], $email['message'] );
+	$email['message'] = str_replace( '###ADMIN_EMAIL###', get_option( 'admin_email' ), $email['message'] );
 	$email['message'] = str_replace( '###EMAIL###', $user->user_email, $email['message'] );
 	$email['message'] = str_replace( '###SITENAME###', $site_name, $email['message'] );
 	$email['message'] = str_replace( '###SITEURL###', home_url(), $email['message'] );
@@ -9575,7 +9575,7 @@ function wp_application_password_created_notification( $user_id, $new_item ) {
 	}

-	/* translators: Do not translate USERNAME, APPLICATION_PASSWORD_NAME, SITENAME, SITEURL, EMAIL: those are placeholders. */
+	/* translators: Do not translate USERNAME, APPLICATION_PASSWORD_NAME, ADMIN_EMAIL, SITENAME, SITEURL, EMAIL: those are placeholders. */
 	$application_password_create_text = __(
 		'Hi ###USERNAME###,